@@ -68,7 +68,7 @@ public class DefaultAlarmVeventDate extends SingleXMLPropertyMixin {
 
     @Override
     protected String getValue() {
-    	return "BEGIN:VALARM&#xD;\r\nEND:VALARM&#xD;\r\n";
+        return "";
     }
 
 }
