@@ -56,11 +56,7 @@ import java.util.Date;
 import java.util.List;
 import java.util.regex.Matcher;
 import java.util.regex.Pattern;
-
 import javax.servlet.http.HttpServletResponse;
-
-import org.apache.commons.logging.Log;
-
 import com.openexchange.carddav.CarddavProtocol;
 import com.openexchange.carddav.GroupwareCarddavFactory;
 import com.openexchange.carddav.Tools;
@@ -90,7 +86,7 @@ import com.openexchange.webdav.protocol.helpers.AbstractCollection;
  */
 public abstract class CardDAVCollection extends AbstractCollection {
 
-    private static final Log LOG = com.openexchange.log.Log.loggerFor(CardDAVCollection.class);
+    private static final org.slf4j.Logger LOG = org.slf4j.LoggerFactory.getLogger(CardDAVCollection.class);
     private static final Pattern LEGACY_FOLDER_NAME = Pattern.compile("f\\d+_(\\d+).vcf");
     private static final long OVERRIDE_LEGACY_FOLDERS = 11;
 
@@ -108,7 +104,7 @@ public abstract class CardDAVCollection extends AbstractCollection {
         this.factory = factory;
         this.url = url;
         super.includeProperties(new SupportedReportSet(), new CTag(factory, this), new SyncToken(this));
-        LOG.debug(getUrl() + ": initialized.");
+        LOG.debug("{}: initialized.", getUrl());
     }
 
     protected WebdavProtocolException protocolException(Throwable t) {
@@ -116,7 +112,7 @@ public abstract class CardDAVCollection extends AbstractCollection {
     }
 
     protected WebdavProtocolException protocolException(Throwable t, int statusCode) {
-        LOG.error(this.getUrl() + ": " + t.getMessage(), t);
+        LOG.error("{}", this.getUrl(), t);
         return WebdavProtocolException.Code.GENERAL_ERROR.create(this.getUrl(), statusCode, t);
     }
 
@@ -206,7 +202,7 @@ public abstract class CardDAVCollection extends AbstractCollection {
             for (Contact contact : this.getContacts()) {
             	children.add(new ContactResource(contact, this.factory, constructPathForChildResource(contact)));
             }
-          	LOG.debug(this.getUrl() + ": added " + children.size() + " contact resources.");
+          	LOG.debug("{}: added {} contact resources.", this.getUrl(), children.size());
             return children;
 		} catch (OXException e) {
             throw protocolException(e);
@@ -247,12 +243,12 @@ public abstract class CardDAVCollection extends AbstractCollection {
 			if (null != overrrideSyncToken && 0 < overrrideSyncToken.length()) {
 				factory.setOverrideNextSyncToken(null);
 				token = overrrideSyncToken;
-				LOG.debug("Overriding sync token to '" + token + "' for user '" + this.factory.getUser() + "'.");
+				LOG.debug("Overriding sync token to '{}' for user '{}'.", token, this.factory.getUser());
 			}
 			try {
 				since = Long.parseLong(token);
 			} catch (NumberFormatException e) {
-				LOG.warn("Invalid sync token: '" + token + "', falling back to '0'.");
+				LOG.warn("Invalid sync token: '{}', falling back to '0'.", token);
 			}
 		}
 		Syncstatus<WebdavResource> syncStatus = null;
@@ -360,8 +356,7 @@ public abstract class CardDAVCollection extends AbstractCollection {
      */
 	public CardDAVResource getChild(String name) throws WebdavProtocolException {
 		if (null != extractLegacyFolderID(name)) {
-			LOG.info(getUrl() + ": client requests legacy simulated group resource '" + name +
-					"', overriding next sync token to '11' for recovery.");
+			LOG.info("{}: client requests legacy simulated group resource '{}', overriding next sync token to '11' for recovery.", getUrl(), name);
 			this.factory.setOverrideNextSyncToken("11");
 			throw protocolException(new Throwable("child resource '" + name + "' not found"), HttpServletResponse.SC_NOT_FOUND);
 		}
@@ -369,10 +364,10 @@ public abstract class CardDAVCollection extends AbstractCollection {
         	String uid = Tools.extractUID(name);
     		Contact contact = this.factory.getState().load(uid);
     		if (null != contact) {
-              	LOG.debug(this.getUrl() + ": found child resource by name '" + name + "'");
+              	LOG.debug("{}: found child resource by name '{}'", this.getUrl(), name);
     			return new ContactResource(contact, this.factory, constructPathForChildResource(contact));
     		} else {
-              	LOG.debug(this.getUrl() + ": child resource '" + name + "' not found, creating placeholder resource");
+              	LOG.debug("{}: child resource '{}' not found, creating placeholder resource", this.getUrl(), name);
     			return new ContactResource(factory, constructPathForChildResource(uid), getFolderID());
     		}
     	} catch (OXException e) {
