@@ -52,9 +52,7 @@ package com.openexchange.carddav.resources;
 import java.io.ByteArrayOutputStream;
 import java.io.IOException;
 import java.util.Date;
-import java.util.TimeZone;
 import javax.servlet.http.HttpServletResponse;
-import org.apache.commons.logging.Log;
 import com.openexchange.carddav.GroupwareCarddavFactory;
 import com.openexchange.carddav.Tools;
 import com.openexchange.carddav.mapping.CardDAVMapper;
@@ -67,7 +65,6 @@ import com.openexchange.tools.versit.Versit;
 import com.openexchange.tools.versit.VersitDefinition;
 import com.openexchange.tools.versit.VersitObject;
 import com.openexchange.tools.versit.converter.ConverterException;
-import com.openexchange.tools.versit.converter.OXContainerConverter;
 import com.openexchange.webdav.protocol.WebdavPath;
 import com.openexchange.webdav.protocol.WebdavProtocolException;
 
@@ -79,8 +76,7 @@ import com.openexchange.webdav.protocol.WebdavProtocolException;
  */
 public class ContactResource extends CardDAVResource {
 
-    private static final Log LOG = com.openexchange.log.Log.loggerFor(ContactResource.class);
-	private static final OXContainerConverter CONVERTER = new OXContainerConverter((TimeZone) null, (String) null);
+    private static final org.slf4j.Logger LOG = org.slf4j.LoggerFactory.getLogger(ContactResource.class);
 	private static final int MAX_RETRIES = 3;
 
     private boolean exists = false;
@@ -127,12 +123,12 @@ public class ContactResource extends CardDAVResource {
 	             * Insert contact
 	             */
 	            this.factory.getContactService().createContact(factory.getSession(), Integer.toString(contact.getParentFolderID()), contact);
-	            LOG.debug(this.getUrl() + ": created.");
+	            LOG.debug("{}: created.", this.getUrl());
 		    } else {
 	            /*
 	             * Insert & delete not supported contact (next sync cleans up the client)
 	             */
-                LOG.warn(this.getUrl() + ": contact groups not supported, performing immediate deletion of this resource.");
+                LOG.warn("{}: contact groups not supported, performing immediate deletion of this resource.", this.getUrl());
 		        contact.removeDistributionLists();
 		        contact.removeNumberOfDistributionLists();
                 this.factory.getContactService().createContact(factory.getSession(), Integer.toString(contact.getParentFolderID()), contact);
@@ -162,7 +158,7 @@ public class ContactResource extends CardDAVResource {
     		 */
         	this.factory.getContactService().deleteContact(factory.getSession(), Integer.toString(contact.getParentFolderID()),
         			Integer.toString(contact.getObjectID()), contact.getLastModified());
-            LOG.debug(this.getUrl() + ": deleted.");
+            LOG.debug("{}: deleted.", this.getUrl());
             this.contact = null;
         } catch (OXException e) {
         	if (handle(e)) {
@@ -182,7 +178,7 @@ public class ContactResource extends CardDAVResource {
         	 */
         	this.factory.getContactService().updateContact(factory.getSession(), Integer.toString(contact.getParentFolderID()),
         			Integer.toString(contact.getObjectID()), contact, contact.getLastModified());
-            LOG.debug(this.getUrl() + ": saved.");
+            LOG.debug("{}: saved.", this.getUrl());
         } catch (OXException e) {
         	if (handle(e)) {
         		save();
@@ -257,7 +253,7 @@ public class ContactResource extends CardDAVResource {
 	                	 * the WebDAV path and the UID field in the vCard, so we need to store this UID in the contact
 	                	 * resource, too, to recognize later updates on the resource.
 	                	 */
-	            		LOG.debug(getUrl() + ": Storing WebDAV resource name in filename.");
+	            		LOG.debug("{}: Storing WebDAV resource name in filename.", getUrl());
 	            		newContact.setFilename(extractedUID);
 	            	}
 	    		}
@@ -284,7 +280,7 @@ public class ContactResource extends CardDAVResource {
 	}
 
 	private Contact deserializeAsContact(VersitObject versitObject) throws OXException, ConverterException {
-		return CONVERTER.convertContact(versitObject);
+		return factory.getConverter().convertContact(versitObject);
 	}
 
     private Contact deserializeAsTemporaryGroup(VersitObject versitObject) throws OXException {
@@ -306,7 +302,7 @@ public class ContactResource extends CardDAVResource {
         VersitDefinition.Writer versitWriter = null;
         try {
             versitWriter = contactDef.getWriter(outputStream, "UTF-8");
-            VersitObject versitObject = CONVERTER.convertContact(contact, "3.0");
+            VersitObject versitObject = factory.getConverter().convertContact(contact, "3.0");
             contactDef.write(versitWriter, versitObject);
             versitWriter.flush();
             return new String(outputStream.toByteArray(), "UTF-8");
@@ -333,7 +329,7 @@ public class ContactResource extends CardDAVResource {
     		/*
     		 * image problem, handle by create without image
     		 */
-        	LOG.warn(this.getUrl() + ": " + e.getMessage() + " - removing image and trying again.");
+        	LOG.warn("{}: {} - removing image and trying again.", this.getUrl(), e.getMessage());
         	this.contact.removeImage1();
         	retry = true;
     	} else if (Tools.isDataTruncation(e)) {
@@ -341,15 +337,15 @@ public class ContactResource extends CardDAVResource {
     		 * handle by trimming truncated fields
     		 */
         	if (this.trimTruncatedAttributes(e)) {
-        		LOG.warn(this.getUrl() + ": " + e.getMessage() + " - trimming fields and trying again.");
+        		LOG.warn("{}: {} - trimming fields and trying again.", this.getUrl(), e.getMessage());
         		retry = true;
         	}
     	} else if (Category.CATEGORY_PERMISSION_DENIED.equals(e.getCategory())) {
     		/*
     		 * handle by overriding sync-token
     		 */
-    		LOG.debug(this.getUrl() + ": " + e.getMessage());
-        	LOG.debug(this.getUrl() + ": overriding next sync token for client recovery.");
+    		LOG.debug("{}: {}", this.getUrl(), e.getMessage());
+        	LOG.debug("{}: overriding next sync token for client recovery.", this.getUrl());
 			this.factory.overrideNextSyncToken();
     	} else if (Category.CATEGORY_CONFLICT.equals(e.getCategory())) {
     		throw super.protocolException(e, HttpServletResponse.SC_CONFLICT);
@@ -369,7 +365,7 @@ public class ContactResource extends CardDAVResource {
 		try {
 			return MappedTruncation.truncate(e.getProblematics(), this.contact);
 		} catch (OXException x) {
-			LOG.warn(getUrl() + ": error trying to handle truncated attributes", x);
+			LOG.warn("{}: error trying to handle truncated attributes", getUrl(), x);
 			return false;
 		}
 	}
