@@ -56,7 +56,6 @@ import java.util.List;
 import java.util.Locale;
 import java.util.regex.Pattern;
 import javax.servlet.http.HttpServletResponse;
-import org.apache.commons.logging.Log;
 import com.openexchange.carddav.GroupwareCarddavFactory;
 import com.openexchange.carddav.mixins.DummySyncToken;
 import com.openexchange.exception.OXException;
@@ -81,7 +80,7 @@ public class RootCollection extends AbstractCollection {
     private static final String EXPOSED_COLLECTIONS_PROPERTY = "com.openexchange.carddav.exposedCollections";
     private static final String REDUCED_AGGREGATED_COLLECTION_PROPERTY = "com.openexchange.carddav.reducedAggregatedCollection";
     private static final String USER_AGENT_FOR_AGGREGATED_COLLECTION_PROPERTY = "com.openexchange.carddav.userAgentForAggregatedCollection";
-    private static final Log LOG = com.openexchange.log.Log.loggerFor(RootCollection.class);
+    private static final org.slf4j.Logger LOG = org.slf4j.LoggerFactory.getLogger(RootCollection.class);
     private static final String DISPLAY_NAME = "Addressbooks";
     private static final String AGGREGATED_FOLDER_ID = "Contacts"; // folder ID needs to be exactly "Contacts" for backwards compatibility
     private static final String AGGREGATED_DISPLAY_NAME = "All Contacts";
@@ -102,7 +101,7 @@ public class RootCollection extends AbstractCollection {
     	this.factory = factory;
     	this.url = new WebdavPath();
         includeProperties(new DummySyncToken());
-        LOG.debug(getUrl() + ": initialized.");
+        LOG.debug("{}: initialized.", getUrl());
     }
 
     protected WebdavProtocolException protocolException(Throwable t) {
@@ -110,7 +109,7 @@ public class RootCollection extends AbstractCollection {
     }
 
     protected WebdavProtocolException protocolException(Throwable t, int statusCode) {
-        LOG.error(t.getMessage(), t);
+        LOG.error("", t);
         return WebdavProtocolException.Code.GENERAL_ERROR.create(this.getUrl(), statusCode, t);
     }
 
@@ -138,7 +137,7 @@ public class RootCollection extends AbstractCollection {
 			 * add the aggregated collection as child resource
 			 */
 			children.add(new AggregatedCollection(factory, constructPathForChildResource(AGGREGATED_FOLDER_ID), AGGREGATED_DISPLAY_NAME));
-			LOG.debug(getUrl() + ": adding aggregated collection as child resource.");
+			LOG.debug("{}: adding aggregated collection as child resource.", getUrl());
 		}
 		if (isUseFolderCollections()) {
 			/*
@@ -147,13 +146,13 @@ public class RootCollection extends AbstractCollection {
 			try {
 				for (UserizedFolder folder : factory.getState().getFolders()) {
 					children.add(new FolderCollection(factory, constructPathForChildResource(folder), folder));
-					LOG.debug(getUrl() + ": adding folder collection for folder '" + folder.getName() + "' as child resource.");
+					LOG.debug("{}: adding folder collection for folder '{}' as child resource.", getUrl(), folder.getName());
 				}
 			} catch (OXException e) {
 				throw protocolException(e);
 			}
 		}
-		LOG.debug(getUrl() + ": got " + children.size() + " child resources.");
+		LOG.debug("{}: got {} child resources.", getUrl(), children.size());
 		return children;
 	}
 
@@ -261,7 +260,7 @@ public class RootCollection extends AbstractCollection {
             try {
                 regex = factory.getConfigValue(USER_AGENT_FOR_AGGREGATED_COLLECTION_PROPERTY, regex);
             } catch (OXException e) {
-                LOG.error("error getting exposed collections from config, falling back to '" + regex + "'", e);
+                LOG.error("error getting exposed collections from config, falling back to '{}'", regex, e);
             }
             userAgentForAggregatedCollection = Pattern.compile(regex, Pattern.CASE_INSENSITIVE);
         }
